@@ -7,6 +7,10 @@ from .sequence import Sequence, SequenceStep, SequenceStepType
 from .prospect import Prospect
 from .prospect_interaction_event import ProspectInteractionEvent, ProspectInteractionEventType
 from .recommendation import Recommendation, RecommendationRejectionReason, RecommendationStatus
+from .utils import (
+    convert_datetime_to_aws_format, get_current_datetime_aws_format, convert_country_str_to_iso_code,
+    convert_date_string_to_datetime_string
+)
 
 
 __all__ = [
@@ -43,4 +47,9 @@ __all__ = [
     "Sequence",
     "SequenceStep",
     "SequenceStepType",
+    # utils
+    "convert_datetime_to_aws_format",
+    "get_current_datetime_aws_format",
+    "convert_country_str_to_iso_code",
+    "convert_date_string_to_datetime_string",
 ]
