@@ -1,10 +1,11 @@
 from dataclasses import dataclass
+from enum import Enum
 
 from dataclasses_json import dataclass_json
 from telescope_sdk.common import UserFacingDataType
 
 
-class CampaignStatus:
+class CampaignStatus(Enum):
     RUNNING = 'RUNNING'
     PAUSED = 'PAUSED'
     ERROR = 'ERROR'
