@@ -35,6 +35,15 @@ class IngestedDataType(TelescopeBaseType):
     version: int
 
 
+@dataclass_json
+@dataclass
+class UserFacingDataType(TelescopeBaseType):
+    """
+    Base data type for entities which are created by or for users and which have a defined owner.
+    """
+    owner: str
+
+
 @dataclass_json
 @dataclass
 class Location:
