@@ -3,7 +3,7 @@ from enum import Enum
 from typing import Optional
 
 from dataclasses_json import dataclass_json
-from telescope_sdk.common import TelescopeBaseType
+from telescope_sdk.common import UserFacingDataType
 
 
 class ProspectInteractionEventType(Enum):
@@ -14,7 +14,7 @@ class ProspectInteractionEventType(Enum):
 
 @dataclass_json
 @dataclass
-class ProspectInteractionEvent(TelescopeBaseType):
+class ProspectInteractionEvent(UserFacingDataType):
     owner: str
     prospect_interaction_event_campaign_id: str
     prospect_id: str
